@@ -8,10 +8,9 @@ import java.util.HashSet;
 
 import OpenSourceExtensions.TDoubleHashSetAndArray;
 import OpenSourceExtensions.UnorderedPair;
+import gnu.trove.list.array.TDoubleArrayList;
 import gnu.trove.list.array.TIntArrayList;
-import it.unimi.dsi.fastutil.doubles.DoubleArrayList;
-import it.unimi.dsi.fastutil.ints.IntArrayList;
-import it.unimi.dsi.fastutil.ints.IntOpenHashSet;
+import gnu.trove.set.hash.TIntHashSet;
 
 /**
  * The class that stores all the information in one node of the BART trees
@@ -70,7 +69,7 @@ public class bartMachineTreeNode implements Cloneable, Serializable {
 	/** the sum of the responses, y */
 	private transient double sum_responses_qty;	
 	/** this caches the possible split variables populated only if the <code>mem_cache_for_speed</code> feature is set to on */
-	private transient IntArrayList possible_rule_variables;
+	private transient TIntArrayList possible_rule_variables;
 	/** this caches the possible split values BY variable populated only if the <code>mem_cache_for_speed</code> feature is set to on */
 	private transient HashMap<Integer, TDoubleHashSetAndArray> possible_split_vals_by_attr;
 	/** this number of possible split variables at this node */
@@ -329,8 +328,8 @@ public class bartMachineTreeNode implements Cloneable, Serializable {
 		//split the data correctly
 		TIntArrayList left_indices = new TIntArrayList(n_eta);  ///////////////THIS MUST BE A TIntArrayList, the fastutil IntArrayList doesn't work here!!!
 		TIntArrayList right_indices = new TIntArrayList(n_eta); ///////////////THIS MUST BE A TIntArrayList, the fastutil IntArrayList doesn't work here!!!
-		DoubleArrayList left_responses = new DoubleArrayList(n_eta);
-		DoubleArrayList right_responses = new DoubleArrayList(n_eta);
+		TDoubleArrayList left_responses = new TDoubleArrayList(n_eta);
+		TDoubleArrayList right_responses = new TDoubleArrayList(n_eta);
 		
 		for (int i = 0; i < n_eta; i++){
 			double[] datum = bart.X_y.get(indicies[i]);
@@ -356,11 +355,11 @@ public class bartMachineTreeNode implements Cloneable, Serializable {
 		}
 		//populate the left daughter
 		left.n_eta = left_responses.size();
-		left.responses = left_responses.elements();
+		left.responses = left_responses.toArray();
 		left.indicies = left_indices.toArray();
 		//populate the right daughter
 		right.n_eta = right_responses.size();
-		right.responses = right_responses.elements();
+		right.responses = right_responses.toArray();
 		right.indicies = right_indices.toArray();
 		//recursively propagate to children
 		left.propagateDataByChangedRule();
@@ -490,7 +489,7 @@ public class bartMachineTreeNode implements Cloneable, Serializable {
 	 * 
 	 * @return		The list of predictors indexed by the columns in the design matrix
 	 */
-	protected IntArrayList predictorsThatCouldBeUsedToSplitAtNode() {
+	protected TIntArrayList predictorsThatCouldBeUsedToSplitAtNode() {
 		if (bart.mem_cache_for_speed){
 			if (possible_rule_variables == null){
 				possible_rule_variables = tabulatePredictorsThatCouldBeUsedToSplitAtNode();
@@ -507,10 +506,10 @@ public class bartMachineTreeNode implements Cloneable, Serializable {
 	 * 
 	 * @return		The list of predictors indexed by the columns in the design matrix
 	 */
-	private IntArrayList tabulatePredictorsThatCouldBeUsedToSplitAtNode() {
-		IntOpenHashSet possible_rule_variables_contenders = null;
+	private TIntArrayList tabulatePredictorsThatCouldBeUsedToSplitAtNode() {
+		TIntHashSet possible_rule_variables_contenders = null;
 		if (bart.mem_cache_for_speed && parent != null){
-			possible_rule_variables_contenders = new IntOpenHashSet();
+			possible_rule_variables_contenders = new TIntHashSet();
 			//check interaction constraints first
 			int m = parent.splitAttributeM;
 			if (bart.interaction_constraints != null && bart.interaction_constraints.containsKey(m)) {
@@ -522,7 +521,7 @@ public class bartMachineTreeNode implements Cloneable, Serializable {
 					
 		}
 
-		IntArrayList possible_rule_variables = new IntArrayList();
+		TIntArrayList possible_rule_variables = new TIntArrayList();
 		for (int j = 0; j < bart.p; j++){
 			if (possible_rule_variables_contenders != null && !possible_rule_variables_contenders.contains(j)) {
 				continue;
