@@ -8,10 +8,11 @@ import java.io.Serializable;
  * 
  * @author Adam Kapelner and Justin Bleich
  */
+@SuppressWarnings("serial")
 public abstract class bartMachine_a_base extends Classifier implements Serializable {
 
 	/** all Gibbs samples for burn-in and post burn-in where each entry is a vector of pointers to the <code>num_trees</code> trees in the sum-of-trees model */
-//	protected bartMachineTreeNode[][] gibbs_samples_of_bart_trees;
+	protected bartMachineTreeNode[][] gibbs_samples_of_bart_trees;
 	/** Gibbs samples post burn-in where each entry is a vector of pointers to the <code>num_trees</code> trees in the sum-of-trees model */
 	protected bartMachineTreeNode[][] gibbs_samples_of_bart_trees_after_burn_in;
 	/** Gibbs samples for burn-in and post burn-in of the variances */
@@ -40,6 +41,8 @@ public abstract class bartMachine_a_base extends Classifier implements Serializa
 	 * @see Section 3.1 of Kapelner, A and Bleich, J. bartMachine: A Powerful Tool for Machine Learning in R. ArXiv e-prints, 2013
 	 */
 	protected boolean mem_cache_for_speed;	
+	/** saves indices in nodes (useful for computing weights) */
+	protected boolean flush_indices_to_save_ram;
 	/** should we print stuff out to screen? */
 	protected boolean verbose = true;
 	
@@ -77,6 +80,10 @@ public abstract class bartMachine_a_base extends Classifier implements Serializa
 	public void setMemCacheForSpeed(boolean mem_cache_for_speed){
 		this.mem_cache_for_speed = mem_cache_for_speed;
 	}
+	
+	public void setFlushIndicesToSaveRAM(boolean flush_indices_to_save_ram) {
+		this.flush_indices_to_save_ram = flush_indices_to_save_ram;
+	}
 
 	public void setNumTrees(int m){
 		this.num_trees = m;
